DragUpdate class

Drag update model which includes the position and size.

Constructors

DragUpdate({required double angle, required Offset position, required Size size, required Size constraints})
Drag update model which includes the position and size.
const

Properties

angle → double
The angle of the draggable asset.
final
constraints → Size
The constraints of the parent view.
final
hashCode → int
The hash code for this object.
no setterinherited
position → Offset
The position of the draggable asset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
The size of the draggable asset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited